nessus-client-go

module
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2026 License: MIT

README ΒΆ

Nessus Client for Go

A lightweight Go Client for interacting with the Nessus API.

πŸ“¦ Installation

go get -u github.com/tencat-dev/nessus-client-go

πŸ” Usage

package main

import (
 "fmt"
 "log"

 "github.com/tencat-dev/nessus-client-go/nessus"
)

func main() {
 // Create a new client with API URL
 client, err := nessus.NewClient(
  nessus.WithApiURL("https://localhost:8834"),
 )
 if err != nil {
  fmt.Println("failed to create client: ", err)
  return
 }

 status, err := client.ServerStatus()
 if err != nil {
  log.Fatalf("failed to get server status: %v", err)
 }
 fmt.Println("Server status: ", status)
}

πŸ“Œ Roadmap

Editors
  • List
  • Details
Folders
  • Create
  • Delete
  • Edit
  • List
Plugins
  • Families
  • Family Details
  • Plugin Details
Scans
  • Attachment Prepare
  • Configure
  • Copy
  • Create
  • Delete
  • Delete Bulk
  • Delete History
  • Details
  • Export Formats
  • Export Download
  • Export Request
  • Export Status
  • Host Details
  • Import
  • Kill
  • Launch
  • List
  • Pause
  • Plugin Output
  • Read Status
  • Resume
  • Schedule
  • Stop
  • Timezones
Server
  • Properties
  • Status
Session
  • Create
  • Destroy
  • Edit
  • Get
  • Password
  • Keys

🀝 Contributing

Contributions are welcome! Please open an issue or submit a pull request.

πŸ“„ License

MIT License

Directories ΒΆ

Path Synopsis
Package nessus implements nessus API
Package nessus implements nessus API

Jump to